##  Use Surveys to Identify and Assign Application Owners
When you start with SAP LeanIX, you might not know all the right people who are familiar with the required data and can take ownership of it. Send surveys to business owners and managers to identify application owners. Business owners and managers can then assign appropriate contributors as fact sheet subscribers. For details, see [Assigning Fact Sheet Subscriptions Through Surveys](https://help.sap.com/docs/leanix/ea/extended-guide-on-survey-features?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759f4557a4410148566fbe869571509__assigning_fact_sheet_subscriptions_through_surveys).
If you select the Allow creating a new subscription user checkbox, the survey recipient can also assign users who haven't been invited to your workspace. Fact sheet subscribers without workspace access are referred to as contacts. They don't receive notifications or surveys from SAP LeanIX. You can invite contacts to your workspace later and assign them a permission role as needed. For more information, see [Contacts](https://help.sap.com/docs/leanix/ea/users-overview?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758f7bb7a4410148ebaeb6edf8d8e3f__contacts).
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio29bf5f3021c54c90971c520403508523_LowRes.png)
Survey for Assigning Fact Sheet Owners
